# FINAM-mHM developers

The FINAM project was created by the following people.

## Core developers

- Sebastian Müller (E-mail: <sebastian.mueller@ufz.de>)

## Working Group members

- Jeisson Javier Leal Rojas (E-mail: <jeisson-javier.leal-rojas@ufz.de>)
- Matthias Kelbling (E-mail: <matthias.kelbling@ufz.de>)
- Martin Lange (E-mail: <martin.lange@ufz.de>)

## Supervisors

- Stephan Thober (E-mail: <stephan.thober@ufz.de>)
- Sabine Attinger (E-mail: <sabine.attinger@ufz.de>)
